@@ -7,11 +7,11 @@
 # instead, and those should come with with 'configure' script so that
 # users do not require the autoconf/automake tools.
 #
-# Scan configure.ac and copy the necessary macros into aclocal.m4.
-aclocal
-# Generate Makefile.in from Makefile.am (and copy necessary support
-# files, because of -ac).
-automake -ac
+# Prepare source package for being internationalized
+set -x
+glib-gettextize --copy --force
+libtoolize --copy --automake
+intltoolize --copy --force --automake
 # This step is not normally necessary, but documented here for your
 # convenience. The files listed below need to be present to stop
 # automake from complaining during various phases of operation.
@@ -19,9 +19,13 @@ automake -ac
 # You also should consider maintaining these files separately once
 # you release your project into the wild.
 #
+# Scan configure.ac and copy the necessary macros into aclocal.m4.
+aclocal-1.9
+autoconf
+# Generate Makefile.in from Makefile.am (and copy necessary support
+# files, because of -ac).
+automake-1.9 --add-missing --copy --foreign
 touch NEWS README AUTHORS ChangeLog
 # Run autoconf (creates the 'configure'-script).
-autoconf
 echo 'Ready to go (run configure)'
 
-
