@@ -161,7 +161,7 @@ int main (int argc, char **argv) {
 			error = NULL;
 			new_game(&d);
 		} else {
-			play_stock_sound(d.sounds, "START");
+			if (s.sound_on) play_stock_sound(d.sounds, "START");
 			current = seq;
 			i = 0;
 			while (i<100 && current != NULL) {
